@@ -502,24 +502,27 @@ void buf_WaitIO(cm_buf_t *bp)
 		if (!(bp->flags & (CM_BUF_READING | CM_BUF_WRITING)))
 			break;
 		
-                /* otherwise I/O is happening, but some other thread is waiting for
-                 * the I/O already.  Wait for that guy to figure out what happened,
-                 * and then check again.
-                 */
-                bp->flags |= CM_BUF_WAITING;
-                osi_SleepM((long) bp, &bp->mx);
-                lock_ObtainMutex(&bp->mx);
-		osi_Log1(buf_logp, "buf_WaitIO conflict wait done for 0x%x", bp);
-        }
-        
-        /* if we get here, the IO is done, but we may have to wakeup people waiting for
-         * the I/O to complete.  Do so.
+        /* otherwise I/O is happening, but some other thread is waiting for
+         * the I/O already.  Wait for that guy to figure out what happened,
+         * and then check again.
          */
-        if (bp->flags & CM_BUF_WAITING) {
+        if ( bp->flags & CM_BUF_WAITING ) 
+            osi_Log1(buf_logp, "buf_WaitIO CM_BUF_WAITING already set for 0x%x", bp);
+
+        bp->flags |= CM_BUF_WAITING;
+        osi_SleepM((long) bp, &bp->mx);
+        lock_ObtainMutex(&bp->mx);
+		osi_Log1(buf_logp, "buf_WaitIO conflict wait done for 0x%x", bp);
+    }
+        
+    /* if we get here, the IO is done, but we may have to wakeup people waiting for
+     * the I/O to complete.  Do so.
+     */
+    if (bp->flags & CM_BUF_WAITING) {
 		bp->flags &= ~CM_BUF_WAITING;
-                osi_Wakeup((long) bp);
-        }
-        osi_Log1(buf_logp, "WaitIO finished wait for bp 0x%x", (long) bp);
+        osi_Wakeup((long) bp);
+    }
+    osi_Log1(buf_logp, "WaitIO finished wait for bp 0x%x", (long) bp);
 }
 
 /* code to drop reference count while holding buf_globalLock */
@@ -1371,44 +1374,45 @@ long buf_CleanVnode(struct cm_scache *scp, cm_user_t *userp, cm_req_t *reqp)
 {
 	long code;
 	cm_buf_t *bp;		/* buffer we're hacking on */
-        cm_buf_t *nbp;		/* next one */
+    cm_buf_t *nbp;		/* next one */
 	long i;
 
 	i = BUF_FILEHASH(&scp->fid);
 
 	code = 0;
 	lock_ObtainWrite(&buf_globalLock);
-        bp = buf_fileHashTablepp[i];
-        if (bp) bp->refCount++;
-        lock_ReleaseWrite(&buf_globalLock);
+    bp = buf_fileHashTablepp[i];
+    if (bp) bp->refCount++;
+    lock_ReleaseWrite(&buf_globalLock);
 	for(; bp; bp = nbp) {
 		/* clean buffer synchronously */
 		if (cm_FidCmp(&bp->fid, &scp->fid) == 0) {
 			if (userp) {
+                cm_HoldUser(userp);
 				lock_ObtainMutex(&bp->mx);
-				if (bp->userp) cm_ReleaseUser(bp->userp);
-                                bp->userp = userp;
+				if (bp->userp) 
+                    cm_ReleaseUser(bp->userp);
+                bp->userp = userp;
 				lock_ReleaseMutex(&bp->mx);
-                                cm_HoldUser(userp);
-                        }
+            }
 			buf_CleanAsync(bp, reqp);
-	                buf_CleanWait(bp);
-                        lock_ObtainMutex(&bp->mx);
+            buf_CleanWait(bp);
+            lock_ObtainMutex(&bp->mx);
 			if (bp->flags & CM_BUF_ERROR) {
 				if (code == 0 || code == -1) code = bp->error;
-                                if (code == 0) code = -1;
-                        }
-                        lock_ReleaseMutex(&bp->mx);
+                if (code == 0) code = -1;
+            }
+            lock_ReleaseMutex(&bp->mx);
 		}
 
 		lock_ObtainWrite(&buf_globalLock);
 		buf_LockedRelease(bp);
-                nbp = bp->fileHashp;
-                if (nbp) nbp->refCount++;
+        nbp = bp->fileHashp;
+        if (nbp) nbp->refCount++;
 		lock_ReleaseWrite(&buf_globalLock);
 	}	/* for loop over a bunch of buffers */
 	
-        /* done */
+    /* done */
 	return code;
 }
 
@@ -1420,6 +1424,9 @@ int cm_DumpBufHashTable(FILE *outputFile, char *cookie)
     char output[1024];
     int i;
   
+	if (buf_hashTablepp == NULL)
+		return -1;
+
     lock_ObtainRead(&buf_globalLock);
   
     sprintf(output, "%s - dumping buf_HashTable - buf_hashSize=%d\n", cookie, buf_hashSize);
