@@ -8,37 +8,39 @@
  */
 
 #include <afsconfig.h>
-#include "../afs/param.h"
+#include "afs/param.h"
 
-RCSID("$Header: /cvs/openafs/src/afs/DARWIN/osi_sleep.c,v 1.3.4.2 2004/10/18 06:04:25 shadow Exp $");
+RCSID
+    ("$Header: /cvs/openafs/src/afs/DARWIN/osi_sleep.c,v 1.9 2003/07/15 23:14:18 shadow Exp $");
 
-#include "../afs/sysincludes.h" /* Standard vendor system headers */
-#include "../afs/afsincludes.h" /* Afs-based standard headers */
-#include "../afs/afs_stats.h"   /* afs statistics */
+#include "afs/sysincludes.h"	/* Standard vendor system headers */
+#include "afsincludes.h"	/* Afs-based standard headers */
+#include "afs/afs_stats.h"	/* afs statistics */
 
 
 static int osi_TimedSleep(char *event, afs_int32 ams, int aintok);
-void afs_osi_Wakeup(char *event);
-void afs_osi_Sleep(char *event);
 
 static char waitV;
 
 
-void afs_osi_InitWaitHandle(struct afs_osi_WaitHandle *achandle)
+void
+afs_osi_InitWaitHandle(struct afs_osi_WaitHandle *achandle)
 {
     AFS_STATCNT(osi_InitWaitHandle);
     achandle->proc = (caddr_t) 0;
 }
 
 /* cancel osi_Wait */
-void afs_osi_CancelWait(struct afs_osi_WaitHandle *achandle)
+void
+afs_osi_CancelWait(struct afs_osi_WaitHandle *achandle)
 {
     caddr_t proc;
 
     AFS_STATCNT(osi_CancelWait);
     proc = achandle->proc;
-    if (proc == 0) return;
-    achandle->proc = (caddr_t) 0;   /* so dude can figure out he was signalled */
+    if (proc == 0)
+	return;
+    achandle->proc = (caddr_t) 0;	/* so dude can figure out he was signalled */
     afs_osi_Wakeup(&waitV);
 }
 
@@ -46,22 +48,24 @@ void afs_osi_CancelWait(struct afs_osi_WaitHandle *achandle)
  * Waits for data on ahandle, or ams ms later.  ahandle may be null.
  * Returns 0 if timeout and EINTR if signalled.
  */
-int afs_osi_Wait(afs_int32 ams, struct afs_osi_WaitHandle *ahandle, int aintok)
+int
+afs_osi_Wait(afs_int32 ams, struct afs_osi_WaitHandle *ahandle, int aintok)
 {
     int code;
     afs_int32 endTime, tid;
-    struct proc *p=current_proc();
+    struct proc *p = current_proc();
 
     AFS_STATCNT(osi_Wait);
-    endTime = osi_Time() + (ams/1000);
+    endTime = osi_Time() + (ams / 1000);
     if (ahandle)
-	ahandle->proc = (caddr_t)p;
+	ahandle->proc = (caddr_t) p;
     do {
 	AFS_ASSERT_GLOCK();
 	code = 0;
 	code = osi_TimedSleep(&waitV, ams, aintok);
 
-	if (code) break;        /* if something happened, quit now */
+	if (code)
+	    break;		/* if something happened, quit now */
 	/* if we we're cancelled, quit now */
 	if (ahandle && (ahandle->proc == (caddr_t) 0)) {
 	    /* we've been signalled */
@@ -74,22 +78,23 @@ int afs_osi_Wait(afs_int32 ams, struct afs_osi_WaitHandle *ahandle, int aintok)
 
 
 typedef struct afs_event {
-    struct afs_event *next;     /* next in hash chain */
-    char *event;                /* lwp event: an address */
-    int refcount;               /* Is it in use? */
-    int seq;                    /* Sequence number: this is incremented
-	                           by wakeup calls; wait will not return until
-	                           it changes */
+    struct afs_event *next;	/* next in hash chain */
+    char *event;		/* lwp event: an address */
+    int refcount;		/* Is it in use? */
+    int seq;			/* Sequence number: this is incremented
+				 * by wakeup calls; wait will not return until
+				 * it changes */
 } afs_event_t;
 
 #define HASHSIZE 128
-afs_event_t *afs_evhasht[HASHSIZE];/* Hash table for events */
+afs_event_t *afs_evhasht[HASHSIZE];	/* Hash table for events */
 #define afs_evhash(event)       (afs_uint32) ((((long)event)>>2) & (HASHSIZE-1));
 int afs_evhashcnt = 0;
 
 /* Get and initialize event structure corresponding to lwp event (i.e. address)
  * */
-static afs_event_t *afs_getevent(char *event)
+static afs_event_t *
+afs_getevent(char *event)
 {
     afs_event_t *evp, *newp = 0;
     int hashcode;
@@ -107,7 +112,7 @@ static afs_event_t *afs_getevent(char *event)
 	evp = evp->next;
     }
     if (!newp) {
-	newp = (afs_event_t *) osi_AllocSmallSpace(sizeof (afs_event_t));
+	newp = (afs_event_t *) osi_AllocSmallSpace(sizeof(afs_event_t));
 	afs_evhashcnt++;
 	newp->next = afs_evhasht[hashcode];
 	afs_evhasht[hashcode] = newp;
@@ -122,7 +127,8 @@ static afs_event_t *afs_getevent(char *event)
 #define relevent(evp) ((evp)->refcount--)
 
 
-void afs_osi_Sleep(char *event)
+void
+afs_osi_Sleep(void *event)
 {
     struct afs_event *evp;
     int seq;
@@ -133,10 +139,10 @@ void afs_osi_Sleep(char *event)
 	AFS_ASSERT_GLOCK();
 	AFS_GUNLOCK();
 #ifdef AFS_DARWIN14_ENV
-        /* this is probably safe for all versions, but testing is hard */
-        sleep(event, PVFS);
+	/* this is probably safe for all versions, but testing is hard */
+	sleep(event, PVFS);
 #else
-	assert_wait((event_t)event, 0);
+	assert_wait((event_t) event, 0);
 	thread_block(0);
 #endif
 	AFS_GLOCK();
@@ -144,6 +150,13 @@ void afs_osi_Sleep(char *event)
     relevent(evp);
 }
 
+int
+afs_osi_SleepSig(void *event)
+{
+    afs_osi_Sleep(event);
+    return 0;
+}
+
 /* osi_TimedSleep
  * 
  * Arguments:
@@ -153,89 +166,66 @@ void afs_osi_Sleep(char *event)
  *
  * Returns 0 if timeout and EINTR if signalled.
  */
-static int osi_TimedSleep(char *event, afs_int32 ams, int aintok)
+static int
+osi_TimedSleep(char *event, afs_int32 ams, int aintok)
 {
     int code = 0;
     struct afs_event *evp;
-    int ticks,seq;
+    int ticks, seq;
     int prio;
 
-    ticks = ( ams * afs_hz )/1000;
+    ticks = (ams * afs_hz) / 1000;
 
 
     evp = afs_getevent(event);
-    seq=evp->seq;
+    seq = evp->seq;
     AFS_GUNLOCK();
 #ifdef AFS_DARWIN14_ENV
     /* this is probably safe for all versions, but testing is hard. */
     /* using tsleep instead of assert_wait/thread_set_timer/thread_block
-       allows shutdown to work in 1.4 */
+     * allows shutdown to work in 1.4 */
     /* lack of PCATCH does *not* prevent signal delivery, neither does 
-       a low priority. We would need to deal with ERESTART here if we 
-       wanted to mess with p->p_sigmask, and messing with p_sigignore is
-       not the way to go.... (someone correct me if I'm wrong)
-    */
+     * a low priority. We would need to deal with ERESTART here if we 
+     * wanted to mess with p->p_sigmask, and messing with p_sigignore is
+     * not the way to go.... (someone correct me if I'm wrong)
+     */
     if (aintok)
-       prio=PCATCH|PPAUSE;
+	prio = PCATCH | PPAUSE;
     else
-       prio=PVFS;
-    code=tsleep(event, prio, "afs_osi_TimedSleep", ticks);
-#else 
-    assert_wait((event_t)event, aintok ? THREAD_ABORTSAFE : THREAD_UNINT);
+	prio = PVFS;
+    code = tsleep(event, prio, "afs_osi_TimedSleep", ticks);
+#else
+    assert_wait((event_t) event, aintok ? THREAD_ABORTSAFE : THREAD_UNINT);
     thread_set_timer(ticks, NSEC_PER_SEC / hz);
     thread_block(0);
-    code=0;
+    code = 0;
 #endif
     AFS_GLOCK();
     if (seq == evp->seq)
 	code = EINTR;
-    
+
     relevent(evp);
     return code;
 }
 
 
-void afs_osi_Wakeup(char *event)
+int
+afs_osi_Wakeup(void *event)
 {
     struct afs_event *evp;
-    
+    int ret = 1;
+
     evp = afs_getevent(event);
     if (evp->refcount > 1) {
-	evp->seq++;    
+	evp->seq++;
 #ifdef AFS_DARWIN14_ENV
-    /* this is probably safe for all versions, but testing is hard. */
-        wakeup(event);
+	/* this is probably safe for all versions, but testing is hard. */
+	wakeup(event);
 #else
-	thread_wakeup((event_t)event);
+	thread_wakeup((event_t) event);
 #endif
+	ret = 0;
     }
     relevent(evp);
-}
-
-void 
-afs_osi_fullSigMask()
-{
-    struct uthread *user_thread = (struct uthread *)get_bsdthread_info(current_act());
-    
-    /* Protect original sigmask */
-    if (!user_thread->uu_oldmask) {
-	/* Back up current sigmask */
-	user_thread->uu_oldmask = user_thread->uu_sigmask;
-	/* Mask all signals */
-	user_thread->uu_sigmask = ~(sigset_t)0;
-    }
-}
-
-void 
-afs_osi_fullSigRestore()
-{
-    struct uthread *user_thread = (struct uthread *)get_bsdthread_info(current_act());
-    
-    /* Protect original sigmask */
-    if (user_thread->uu_oldmask) {
-	/* Restore original sigmask */
-	user_thread->uu_sigmask = user_thread->uu_oldmask;
-	/* Clear the oldmask */
-	user_thread->uu_oldmask = (sigset_t)0;
-    }
+    return ret;
 }
